==> telegram_client-0.5.45.tar.gz: lib/telegram_client/function/unban_chat_member.dart <==
// ignore_for_file: non_constant_identifier_names, camel_case_extensions

import 'dart:async';
import 'package:telegram_client/telegram_client/scheme/json_dart.dart';
import 'package:telegram_client/telegram_client/telegram_client.dart';

import 'package:telegram_client/telegram_client/scheme/json_dart.dart'
    as scheme;
import 'package:telegram_client/util/util.dart';

import 'package:galaxeus_lib/extension/extension.dart';

/// method UnbanChatMember
extension UnbanChatMemberDataOn on TelegramClient {
  /// method UnbanChatMember
  FutureOr<JsonScheme> unbanChatMember({
    required Map parameters,
    required FutureOr<JsonScheme> Function({
      required Map parameters,
    }) callApiInvoke,
    required TelegramClientData telegramClientData,
  }) async {
    dynamic target_chat_id = TgUtils.parse_all_chat_id(parameters: parameters);
    if (target_chat_id is String &&
        RegExp(r"^((@)[a-z0-9_]+)$", caseSensitive: false)
            .hashData(target_chat_id)) {
      var search_public_chat = await callApiInvoke(
        parameters: {
          "@type": "searchPublicChat",
          "username": (target_chat_id)
              .replaceAll(RegExp(r"@", caseSensitive: false), ""),
        },
      );
      if (search_public_chat["@type"] == "chat") {
        parameters["chat_id"] = search_public_chat["id"];
      }
    }
    Map request_parameters = {
      "@type": "setChatMemberStatus",
      "chat_id": parameters["chat_id"],
      "member_id": {
        "@type": "messageSenderUser",
        "user_id": parameters["user_id"],
      },
      "status": {
        "@type": "chatMemberStatusLeft",
      }
    };

    scheme.JsonScheme request_result = await invoke(
      parameters: request_parameters,
      telegramClientData: telegramClientData,
    );

    return request_result;
  }
}

==> telegram_client-0.5.56.tar.gz: lib/telegram_client/function/unban_chat_member.dart <==
// ignore_for_file: non_constant_identifier_names, camel_case_extensions

import 'dart:async';

import 'package:telegram_client/telegram_client/telegram_client.dart';

import 'package:telegram_client/util/util.dart';

import 'package:galaxeus_lib/extension/extension.dart';

/// method UnbanChatMember
extension UnbanChatMemberDataOn on TelegramClient {
  /// method UnbanChatMember
  FutureOr<Map> unbanChatMember({
    required Map parameters,
    required FutureOr<Map> Function({
      required Map parameters,
    }) callApiInvoke,
    required TelegramClientData telegramClientData,
  }) async {
    dynamic target_chat_id = TgUtils.parse_all_chat_id(parameters: parameters);
    if (target_chat_id is String &&
        RegExp(r"^((@)[a-z0-9_]+)$", caseSensitive: false)
            .hashData(target_chat_id)) {
      var search_public_chat = await callApiInvoke(
        parameters: {
          "@type": "searchPublicChat",
          "username": (target_chat_id)
              .replaceAll(RegExp(r"@", caseSensitive: false), ""),
        },
      );
      if (search_public_chat["@type"] == "chat") {
        parameters["chat_id"] = search_public_chat["id"];
      }
    }
    Map request_parameters = {
      "@type": "setChatMemberStatus",
      "chat_id": parameters["chat_id"],
      "member_id": {
        "@type": "messageSenderUser",
        "user_id": parameters["user_id"],
      },
      "status": {
        "@type": "chatMemberStatusLeft",
      }
    };

    Map request_result = await invoke(
      parameters: request_parameters,
      telegramClientData: telegramClientData,
    );

    return request_result;
  }
}
